==> kadu_0.10.1.orig.tar.bz2: kadu-0.10.1/kadu-core/configuration/toolbar-configuration-manager.cpp <==
/*
 * %kadu copyright begin%
 * Copyright 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
 * %kadu copyright end%
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include <QtCore/QTimer>

#include "gui/actions/actions.h"

#include "toolbar-configuration-manager.h"

ToolbarConfigurationManager::ToolbarConfigurationManager(QObject *parent) :
		QObject(parent)
{
	connect(Actions::instance(), SIGNAL(actionLoaded(QString)), this, SIGNAL(configurationUpdated()));
	connect(Actions::instance(), SIGNAL(actionUnloaded(QString)), this, SIGNAL(configurationUpdated()));
}

ToolbarConfigurationManager::~ToolbarConfigurationManager()
{
	disconnect(Actions::instance(), SIGNAL(actionLoaded(QString)), this, SIGNAL(configurationUpdated()));
	disconnect(Actions::instance(), SIGNAL(actionUnloaded(QString)), this, SIGNAL(configurationUpdated()));
}

void ToolbarConfigurationManager::notifyConfigurationUpdated()
{
	// do not use '0' here, with '50' there is no flicking
	QTimer::singleShot(50, this, SIGNAL(configurationUpdated()));
}

==> kadu_1.2.orig.tar.bz2: kadu-1.2/kadu-core/configuration/toolbar-configuration-manager.cpp <==
/*
 * %kadu copyright begin%
 * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
 * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
 * Copyright 2007, 2008, 2009, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
 * Copyright 2011, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
 * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
 * %kadu copyright end%
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include <QtCore/QTimer>

#include "toolbar-configuration-manager.h"

ToolbarConfigurationManager::ToolbarConfigurationManager(QObject *parent) :
		QObject(parent)
{
}

ToolbarConfigurationManager::~ToolbarConfigurationManager()
{
}

void ToolbarConfigurationManager::notifyConfigurationUpdated()
{
	// do not use '0' here, with '50' there is no flicking
	QTimer::singleShot(50, this, SIGNAL(configurationUpdated()));
}

#include "moc_toolbar-configuration-manager.cpp"
